==========
DummyTrash
==========
:Name: DummyTrash
:Module: dummytrash
:Author: Chris Warrick <chris@chriswarrick.com>
:Specification: n/a
:OS: any
:Description: A dummy backend, printing all the requests it gets.
:Copyright: © 2011–2015, Chris Warrick.
:License: BSD (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2015-02-28
:Version: 1.5.0

.. index:: DummyTrash

.. automodule:: trashman.backends.dummytrash
   :members:
